@@ -30,9 +30,9 @@ import com.openexchange.mobile.configuration.generator.configuration.MobileConfi
 import com.openexchange.mobile.configuration.generator.configuration.Property;
 import com.openexchange.mobile.configuration.generator.osgi.Activator;
 import com.openexchange.mobile.configuration.generator.services.MobileConfigServiceRegistry;
+import com.openexchange.templating.base.TemplateService;
 import com.openexchange.templating.base.OXTemplate;
 import com.openexchange.templating.base.TemplateException;
-import com.openexchange.templating.base.TemplateService;
 import com.openexchange.tools.servlet.http.Tools;
 
 
@@ -142,8 +142,6 @@ public class MobileConfigServlet extends HttpServlet {
         CabUtil.writeCabFile(new DataOutputStream(new BufferedOutputStream(out)), write(email, host, username, domain));
     }
 
-    private static final Pattern PATTERN_CRLF = Pattern.compile("\r?\n|(?:%0[aA])?%0[dD]");
-
     @Override
     public void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         resp.setCharacterEncoding("UTF-8");
@@ -196,11 +194,11 @@ public class MobileConfigServlet extends HttpServlet {
             if (null != header) {
                 if (header.matches(iphoneRegEx)) {
                     // iPhone part
-                    resp.sendRedirect(Activator.ALIAS + "/eas.mobileconfig?l=" + PATTERN_CRLF.matcher(URLEncoder.encode(login,"UTF-8")).replaceAll("") + mailpart);
+                    resp.sendRedirect(Activator.ALIAS + "/eas.mobileconfig?l=" + URLEncoder.encode(login,"UTF-8") + mailpart);
                     return;
                 } else if (header.matches(winMobRegEx)) {
                     // WinMob part
-                    resp.sendRedirect(Activator.ALIAS + "/ms.cab?l=" + PATTERN_CRLF.matcher(URLEncoder.encode(login,"UTF-8")).replaceAll("") + mailpart);
+                    resp.sendRedirect(Activator.ALIAS + "/ms.cab?l=" + URLEncoder.encode(login,"UTF-8") + mailpart);
                     return;
                 } else {
                     printError(req, resp, ErrorMessage.MSG_NO_SUPPORTED_DEVICE_FOUND);
@@ -363,7 +361,7 @@ public class MobileConfigServlet extends HttpServlet {
     }
 
     private void printError(HttpServletRequest req, final HttpServletResponse resp, final ErrorMessage string) throws IOException {
-        resp.sendRedirect(Activator.ALIAS + "?error=" + Integer.toString(string.ordinal()));
+        resp.sendRedirect(Activator.ALIAS + "?error=" + URLEncoder.encode(String.valueOf(string.ordinal()),"UTF-8"));
     }
 
     private void writeMobileConfig(final PrintWriter printWriter, OutputStream outStream, final String email, final String host, final String username, final String domain) throws IOException, TemplateException, ConfigurationException {
